@@ -1,12 +1,12 @@
 package App::lcpan::Cmd::rt_open;
 
-our $DATE = '2017-02-03'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 require App::lcpan;
 
@@ -69,7 +69,7 @@ App::lcpan::Cmd::rt_open - Open RT page for dist/module
 
 =head1 VERSION
 
-This document describes version 0.002 of App::lcpan::Cmd::rt_open (from Perl distribution App-lcpan-CmdBundle-rt), released on 2017-02-03.
+This document describes version 0.003 of App::lcpan::Cmd::rt_open (from Perl distribution App-lcpan-CmdBundle-rt), released on 2017-07-10.
 
 =head1 DESCRIPTION
 
